@@ -1,5 +1,5 @@
 #!/usr/bin/python
-# MySqlPy V1.5.2
+# MySqlPy V1.6.0
 # Author: Luca.Canali@cern.ch
 # 
 #
@@ -13,9 +13,9 @@ import sys, tempfile, optparse, unittest
 
 class mysqlpy(sqlpyPlus):
     '''
-MySqlPy V1.4.9 - 'sqlplus in python'
+MySqlPy V1.6.0 - 'sqlplus in python'
 Author: Luca.Canali@cern.ch
-Rev: 1.4.9, 26-Sep-08
+Rev: 1.6.0, 02-Mar-09
 
 Companion of SqlPython, a python module that reproduces Oracle's command line within python
 and sqlpyPlus. Major contributions by Catherine Devlin, http://catherinedevlin.blogspot.com
@@ -140,6 +140,10 @@ which get and run SQL scripts from disk.'''
 
     def do_explain(self,args):
         '''prints the plan of a given statement from the sql cache. 1 parameter: sql_id, see also do_sql '''
+        if len(args) > 2 and args[0].lower() == 'plan' and args[1].lower() == 'for':
+            self.curs.execute('explain %s' % ' '.join(args))
+            print 'Explained.  (see plan table)'
+            return 
         self.query = "select * from table(dbms_xplan.display_cursor('"+args+"'))"
         try:
             self.curs.execute(self.query)
